package com.vandyo.sentry.core.cases;

import cn.hutool.http.HttpRequest;
import cn.hutool.http.HttpResponse;
import cn.hutool.json.JSONObject;
import cn.hutool.json.JSONUtil;
import com.vandyo.sentry.core.collectionMachine.CollectionMachine;
import com.vandyo.sentry.core.dto.Res;
import com.vandyo.sentry.core.tools.Signature;

import java.util.HashMap;
import java.util.Map;


/**
 * 获取用户信息接口
 */
public class UserInfoDecorator extends CaseDecorator {

    private final static String UserInfoUrl = "/user/info/get";

    public UserInfoDecorator(Case aCase) {
        super(aCase);
    }

    @Override
    public Res<Map<String, String>> check() {
        Res<Map<String, String>> oldRes = super.check();
        if (oldRes.getSuccess()) {
            Map<String, String> data = new HashMap<>();
            data.put("uid", oldRes.getUId());
            HttpResponse response = HttpRequest.get(Signature.host + UserInfoUrl + "?"
                    + Signature.getUrlParamsByMap(Signature.sign(data, oldRes.getSId())))
                    .execute();
            Res<Map<String, String>> newRes = new Res<>();
            newRes.setSId(oldRes.getSId());
            newRes.setUId(oldRes.getUId());

            if (response.isOk()) {
                JSONObject json = JSONUtil.parseObj(response.body());
                newRes.setSuccess(true);
            } else {
                newRes.setKey(UserInfoUrl);
                newRes.setStatus(Signature.matchStatus(response.getStatus()));
                newRes.setSuccess(false);
            }
            CollectionMachine.post(newRes);
            return newRes;
        } else {
            oldRes.setIgnore(true);
            return oldRes;
        }
    }
}